@@ -18,7 +18,7 @@ use Exception::Class (
 );
 use Minions::_Guts;
 
-our $VERSION = '0.000005';
+our $VERSION = '0.000006';
 $VERSION = eval $VERSION;
 
 my $Class_count = 0;
@@ -662,7 +662,9 @@ and "OOP to me means only messaging, local retention and protection and hiding o
 
 Due to Perl's "assembly required" approach to OOP, there are many CPAN modules that exist to automate this assembly,
 perhaps the most popular being the L<Moose> family. Moo(se) is very effective at simplifying class building but this is typically achieved at the
-expense of Encapsulation (the hiding of implementation details from end users).
+expense of L<Encapsulation|https://en.wikipedia.org/wiki/Information_hiding> (the hiding of implementation details from end users).
+
+To see this first hand, try writing the fixed size queue from L<Minions::Implementation/OBJECT COMPOSITION> using L<Moo>, bearing in mind that the only operations the queue should allow are C<push>, C<pop> and C<size>. It is also a revealing exercise to consider how this queue would be written in Ruby or PHP (e.g. would you need to expose all object attributes via methods?). 
 
 Minions takes inspriation from Moose's declaratve approach to simplifying OO automation, but does not require or encourage encapsulation to be sacrificed.
 
@@ -760,16 +762,6 @@ The class defined in the SYNOPSIS could also be defined like this
     is $counter->next => 0;
     is $counter->next => 1;
 
-=head2 Examples
-
-Further examples of usage can be found in the following documents
-
-=over 4
-
-=item L<Minions::Manual::Construction>
-
-=back
-
 =head2 Specification
 
 The meaning of the keys in the specification hash are described next.
@@ -788,6 +780,8 @@ An optional reference to a hash whose keys are the names of keyword parameters t
 
 The values these keys are mapped to are themselves hash refs which can have the following keys.
 
+See L<Minions::Manual::Construction> for more about construction.
+
 =head4 optional => BOOLEAN (Default: false)
 
 If this is set to a true value, then the corresponding key/value pair need not be passed to the constructor.
