@@ -3,7 +3,7 @@ package Example::Construction::Counter_v2;
 use strict;
 use Minions ();
 
-our %__Meta = (
+our %__meta__ = (
     interface => [ qw( next ) ],
 
     construct_with => {
@@ -19,10 +19,9 @@ our %__Meta = (
 sub new {
     my ($class, $start) = @_;
 
-    my $utility_class = Minions::utility_class($class);
-    $utility_class->assert('start' => $start);
-    my $obj = $utility_class->new_object;
-    $obj->{$$}{count} = $start;
+    my $util = Minions::utility_class($class);
+    $util->assert(start => $start);
+    my $obj = $util->new_object({count => $start});
     return $obj;
 }
 
